({ modulesPath, config, lib, pkgs, ... }: {
  imports = [
    ./modules
    ./virtualisation.nix
    ./common-config
    ./games.nix
    ./retroarch
  ];

  system.stateVersion = "23.11";
  boot.loader.systemd-boot.enable = true;

  environment.systemPackages = [
    pkgs.xorg.xorgserver
    pkgs.xorg.xinit
    pkgs.xorg.xf86inputevdev
    pkgs.xorg.xf86inputsynaptics
    pkgs.xorg.xf86inputlibinput
    pkgs.xorg.xf86videointel
    pkgs.xorg.xf86videoati
    pkgs.xorg.xf86videonouveau
  ];

  programs.bash.loginShellInit =
    "startx ${config.retronix.emulationstation.cli}";

  hardware.opengl.enable = true;
  hardware.opengl.driSupport = true;
  services.xserver.enable = true;
  services.xserver.displayManager.startx.enable = true;
  services.xserver.libinput.enable = true;

  users.mutableUsers = false;
  users.users.arcade = {
    isNormalUser = true;
    home = "/home/arcade";
    extraGroups = [ "wheel" ];
    inherit (import ./opsec.nix) hashedPassword;
  };
  services.getty.autologinUser = "arcade";

  nixpkgs.overlays = [ (import ./pkgs/overlay.nix) ];

  console.keyMap = "fr";
})
